@@ -13,9 +13,7 @@ This provides only the 2.0 D-Bus API of low-memory-monitor.
 # of the license.
 
 __author__ = 'Bastien Nocera'
-__email__ = 'hadess@hadess.net'
 __copyright__ = '(c) 2019, Red Hat Inc.'
-__license__ = 'LGPL 3+'
 
 import dbus
 
@@ -27,7 +25,7 @@ MAIN_IFACE = 'org.freedesktop.LowMemoryMonitor'
 SYSTEM_BUS = True
 
 
-def load(mock, parameters):
+def load(mock, _parameters):
     # Loaded!
     mock.loaded = True
 
